==> pointblank_0.5.1.tar.gz: pointblank/tests/testthat/tests/testthat/dbo/SELECT-b26d98.R <==
structure(list(tailnum = c("N14558", "N15555", "N15574", "N174US", 
"N177US", "N181UW", "N18557", "N194UW", "N238JB", "N271LV", "N272AT", 
"N281AT", "N298WN", "N299WN", "N301DQ", "N308DE", "N315AT", "N331NB", 
"N33292", "N345NB", "N377AA", "N389HA", "N398AA", "N466UA", "N517AA", 
"N521AA", "N527AS", "N528AA", "N531JB", "N53441", "N536AA", "N540AA", 
"N611QX", "N670UA", "N673AW", "N705UW", "N729JB", "N73278", "N752EV", 
"N75426", "N755EV", "N76503", "N76505", "N76514", "N767SW", "N7812G", 
"N799SW", "N826AW", "N828AW", "N8303R", "N830AW", "N834AW", "N835AW", 
"N841VA", "N846AS", "N8606C", "N8894A", "N915FJ", "N920DN", "N921DN", 
"N923DN", "N926WN", "N927WN", "N928DN", "N928WN", "N937DN", "N945UW", 
"N953DN", "N983AT", "N991AT"), year = c(NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_), type = c("Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing single engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing single engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing single engine", 
"Fixed wing single engine", "Fixed wing multi engine", "Fixed wing single engine", 
"Fixed wing single engine", "Fixed wing multi engine", "Fixed wing single engine", 
"Fixed wing single engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine"
), manufacturer = c("EMBRAER", "EMBRAER", "EMBRAER", "AIRBUS INDUSTRIE", 
"AIRBUS INDUSTRIE", "AIRBUS INDUSTRIE", "EMBRAER", "AIRBUS", 
"EMBRAER", "BOEING", "BOEING", "AIRBUS INDUSTRIE", "BOEING", 
"BOEING", "BOEING", "BOEING", "JOHN G HESS", "AIRBUS INDUSTRIE", 
"BOEING", "AIRBUS", "PAIR MIKE E", "AIRBUS", "LEARJET INC", "AIRBUS INDUSTRIE", 
"HURLEY JAMES LARRY", "STEWART MACO", "BOEING", "LAMBERT RICHARD", 
"BARKER JACK L", "BOEING", "AMERICAN AIRCRAFT INC", "AMERICAN AIRCRAFT INC", 
"BOMBARDIER INC", "BOEING", "AIRBUS", "AIRBUS INDUSTRIE", "AIRBUS", 
"BOEING", "BOMBARDIER INC", "BOEING", "BOMBARDIER INC", "BOEING", 
"BOEING", "BOEING", "BOEING", "BOEING", "BOEING", "AIRBUS INDUSTRIE", 
"AIRBUS INDUSTRIE", "BOEING", "AIRBUS INDUSTRIE", "AIRBUS", "AIRBUS", 
"AIRBUS", "BOMBARDIER INC", "BOEING", "BOMBARDIER INC", "BOMBARDIER INC", 
"MCDONNELL DOUGLAS", "MCDONNELL DOUGLAS", "BOEING", "BOEING", 
"BOEING", "BOEING", "BOEING", "MCDONNELL DOUGLAS", "EMBRAER", 
"MCDONNELL DOUGLAS", "BOEING", "BOEING"), model = c("EMB-145LR", 
"EMB-145LR", "EMB-145LR", "A321-211", "A321-211", "A321-211", 
"EMB-145LR", "A321-211", "ERJ 190-100 IGW", "737-705", "777-200", 
"A340-313", "737-7H4", "737-7H4", "737-732", "737-732", "AT-5", 
"A319-114", "737-824", "A319-114", "FALCON XP", "A330-243", "60", 
"A320-232", "FALCON-XP", "FALCON-XP", "737-890", "FALCON XP", 
"ZODIAC 601HDS", "737-924ER", "FALCON XP", "FALCON XP", "CL-600-2C10", 
"767-322", "A320-232", "A319-112", "A320-232", "737-824", "CL-600-2C10", 
"737-924ER", "CL-600-2C10", "737-824", "737-824", "737-824", 
"737-7H4", "737-76N", "737-7Q8", "A319-132", "A319-132", "737-8H4", 
"A319-132", "A319-132", "A319-132", "A320-214", "CL-600-2B19", 
"737-8H4", "CL-600-2B19", "CL-600-2D24", "MD-90-30", "MD-90-30", 
"MD-90-30", "737-7H4", "737-7H4", "MD-90-30", "737-7H4", "MD-90-30", 
"ERJ 190-100 IGW", "MD-90-30", "717-200", "717-200"), engines = c(2L, 
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 4L, 2L, 2L, 2L, 2L, 1L, 
2L, 2L, 2L, 1L, 2L, 2L, 2L, 1L, 1L, 2L, 1L, 1L, 2L, 1L, 1L, 2L, 
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 
2L, 2L, 2L, 2L, 2L), seats = c(55L, 55L, 55L, 199L, 199L, 199L, 
55L, 199L, 20L, 149L, 400L, 375L, 140L, 140L, 149L, 149L, 2L, 
145L, 149L, 145L, 2L, 377L, 11L, 200L, 2L, 2L, 149L, 2L, 2L, 
191L, 2L, 2L, 80L, 330L, 200L, 179L, 200L, 149L, 80L, 191L, 80L, 
149L, 149L, 149L, 140L, 149L, 149L, 179L, 179L, 140L, 179L, 179L, 
179L, 182L, 55L, 140L, 55L, 95L, 142L, 142L, 142L, 140L, 140L, 
142L, 140L, 142L, 20L, 142L, 100L, 100L), speed = c(NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_), engine = c("Turbo-fan", 
"Turbo-fan", "Turbo-fan", "Turbo-jet", "Turbo-jet", "Turbo-jet", 
"Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-jet", 
"Turbo-jet", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", 
"4 Cycle", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Reciprocating", 
"Turbo-fan", "Turbo-fan", "Turbo-fan", "Reciprocating", "Reciprocating", 
"Turbo-fan", "Reciprocating", "Reciprocating", "Turbo-fan", "Reciprocating", 
"Reciprocating", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", 
"Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", 
"Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", 
"Turbo-fan", "Turbo-jet", "Turbo-jet", "Turbo-fan", "Turbo-jet", 
"Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", 
"Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", 
"Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", 
"Turbo-fan", "Turbo-jet", "Turbo-fan", "Turbo-fan")), class = "data.frame", row.names = c(NA, 
-70L))

==> pointblank_0.10.0.tar.gz: pointblank/tests/testthat/tests/testthat/dbo/SELECT-b26d98.R <==
structure(list(tailnum = c("N14558", "N15555", "N15574", "N174US", 
"N177US", "N181UW", "N18557", "N194UW", "N238JB", "N271LV", "N272AT", 
"N281AT", "N298WN", "N299WN", "N301DQ", "N308DE", "N315AT", "N331NB", 
"N33292", "N345NB", "N377AA", "N389HA", "N398AA", "N466UA", "N517AA", 
"N521AA", "N527AS", "N528AA", "N531JB", "N53441", "N536AA", "N540AA", 
"N611QX", "N670UA", "N673AW", "N705UW", "N729JB", "N73278", "N752EV", 
"N75426", "N755EV", "N76503", "N76505", "N76514", "N767SW", "N7812G", 
"N799SW", "N826AW", "N828AW", "N8303R", "N830AW", "N834AW", "N835AW", 
"N841VA", "N846AS", "N8606C", "N8894A", "N915FJ", "N920DN", "N921DN", 
"N923DN", "N926WN", "N927WN", "N928DN", "N928WN", "N937DN", "N945UW", 
"N953DN", "N983AT", "N991AT"), year = c(NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_), type = c("Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing single engine", "Fixed wing multi engine",
"Fixed wing multi engine", "Fixed wing multi engine",
"Fixed wing single engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine",
"Fixed wing single engine", "Fixed wing single engine",
"Fixed wing multi engine", "Fixed wing single engine", 
"Fixed wing single engine", "Fixed wing multi engine",
"Fixed wing single engine", "Fixed wing single engine",
"Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine", 
"Fixed wing multi engine", "Fixed wing multi engine", "Fixed wing multi engine"
), manufacturer = c("EMBRAER", "EMBRAER", "EMBRAER", "AIRBUS INDUSTRIE", 
"AIRBUS INDUSTRIE", "AIRBUS INDUSTRIE", "EMBRAER", "AIRBUS", 
"EMBRAER", "BOEING", "BOEING", "AIRBUS INDUSTRIE", "BOEING", 
"BOEING", "BOEING", "BOEING", "JOHN G HESS", "AIRBUS INDUSTRIE", 
"BOEING", "AIRBUS", "PAIR MIKE E", "AIRBUS", "LEARJET INC", "AIRBUS INDUSTRIE", 
"HURLEY JAMES LARRY", "STEWART MACO", "BOEING", "LAMBERT RICHARD", 
"BARKER JACK L", "BOEING", "AMERICAN AIRCRAFT INC", "AMERICAN AIRCRAFT INC", 
"BOMBARDIER INC", "BOEING", "AIRBUS", "AIRBUS INDUSTRIE", "AIRBUS", 
"BOEING", "BOMBARDIER INC", "BOEING", "BOMBARDIER INC", "BOEING", 
"BOEING", "BOEING", "BOEING", "BOEING", "BOEING", "AIRBUS INDUSTRIE", 
"AIRBUS INDUSTRIE", "BOEING", "AIRBUS INDUSTRIE", "AIRBUS", "AIRBUS", 
"AIRBUS", "BOMBARDIER INC", "BOEING", "BOMBARDIER INC", "BOMBARDIER INC", 
"MCDONNELL DOUGLAS", "MCDONNELL DOUGLAS", "BOEING", "BOEING", 
"BOEING", "BOEING", "BOEING", "MCDONNELL DOUGLAS", "EMBRAER", 
"MCDONNELL DOUGLAS", "BOEING", "BOEING"), model = c("EMB-145LR", 
"EMB-145LR", "EMB-145LR", "A321-211", "A321-211", "A321-211", 
"EMB-145LR", "A321-211", "ERJ 190-100 IGW", "737-705", "777-200", 
"A340-313", "737-7H4", "737-7H4", "737-732", "737-732", "AT-5", 
"A319-114", "737-824", "A319-114", "FALCON XP", "A330-243", "60", 
"A320-232", "FALCON-XP", "FALCON-XP", "737-890", "FALCON XP", 
"ZODIAC 601HDS", "737-924ER", "FALCON XP", "FALCON XP", "CL-600-2C10", 
"767-322", "A320-232", "A319-112", "A320-232", "737-824", "CL-600-2C10", 
"737-924ER", "CL-600-2C10", "737-824", "737-824", "737-824", 
"737-7H4", "737-76N", "737-7Q8", "A319-132", "A319-132", "737-8H4", 
"A319-132", "A319-132", "A319-132", "A320-214", "CL-600-2B19", 
"737-8H4", "CL-600-2B19", "CL-600-2D24", "MD-90-30", "MD-90-30", 
"MD-90-30", "737-7H4", "737-7H4", "MD-90-30", "737-7H4", "MD-90-30", 
"ERJ 190-100 IGW", "MD-90-30", "717-200", "717-200"), engines = c(2L, 
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 4L, 2L, 2L, 2L, 2L, 1L, 
2L, 2L, 2L, 1L, 2L, 2L, 2L, 1L, 1L, 2L, 1L, 1L, 2L, 1L, 1L, 2L, 
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 
2L, 2L, 2L, 2L, 2L), seats = c(55L, 55L, 55L, 199L, 199L, 199L, 
55L, 199L, 20L, 149L, 400L, 375L, 140L, 140L, 149L, 149L, 2L, 
145L, 149L, 145L, 2L, 377L, 11L, 200L, 2L, 2L, 149L, 2L, 2L, 
191L, 2L, 2L, 80L, 330L, 200L, 179L, 200L, 149L, 80L, 191L, 80L, 
149L, 149L, 149L, 140L, 149L, 149L, 179L, 179L, 140L, 179L, 179L, 
179L, 182L, 55L, 140L, 55L, 95L, 142L, 142L, 142L, 140L, 140L, 
142L, 140L, 142L, 20L, 142L, 100L, 100L), speed = c(NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_), engine = c("Turbo-fan", 
"Turbo-fan", "Turbo-fan", "Turbo-jet", "Turbo-jet", "Turbo-jet", 
"Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-jet", 
"Turbo-jet", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", 
"4 Cycle", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Reciprocating", 
"Turbo-fan", "Turbo-fan", "Turbo-fan", "Reciprocating", "Reciprocating", 
"Turbo-fan", "Reciprocating", "Reciprocating", "Turbo-fan", "Reciprocating", 
"Reciprocating", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", 
"Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", 
"Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", 
"Turbo-fan", "Turbo-jet", "Turbo-jet", "Turbo-fan", "Turbo-jet", 
"Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", 
"Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", 
"Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", "Turbo-fan", 
"Turbo-fan", "Turbo-jet", "Turbo-fan", "Turbo-fan")),
class = "data.frame", row.names = c(NA, -70L))
